//=====================================================
//      Name:            FOV_Calculator.java
//      Project:         PINHOLE CAMERA MODEL FOR IMAGEJ
//      Version:         0.1
//
//      Author:           Joshua Gulick, Orphan Technologies, Inc.
//      Date:               5/30/2000
//      Comment:        Determines the field of view for a particular camera setup
//=====================================================

import ij.*;
import ij.plugin.*;
import ij.gui.*;
import ij.process.*;

public class FOV_Calculator implements PlugIn {

        public void run(String arg) {
                double sx=0, sy=0, sz=0, px=17.5, py=12, pz=15, sw=35.0, sh=24, pd = py-sy;
                GenericDialog gd = new GenericDialog("Field-of-view Calculator");
                gd.addNumericField("Sensor Origin X: ", sx, 1);
                gd.addNumericField("Sensor Origin Y: ", sy, 1);
                gd.addNumericField("Sensor Origin Z: ", sz, 1);
                gd.addNumericField("Pinhole X: ", px, 1);
                gd.addNumericField("Pinhole Y: ", py, 1);
                gd.addNumericField("Pinhole Z: ", pz, 1);
                gd.addNumericField("Sensor Width: ", sw, 1);
                gd.addNumericField("Sensor Height: ", sh, 1);
                gd.addMessage("Please enter camera parameters.");
                gd.showDialog();
                if (gd.wasCanceled())
                        return;
                sx = gd.getNextNumber();
                sy = gd.getNextNumber();
                sz = gd.getNextNumber();
                px = gd.getNextNumber();
                py = gd.getNextNumber();
                pz = gd.getNextNumber();
                sw = gd.getNextNumber();
                sh = gd.getNextNumber();
                pd = py-sy;
                double leftSensorWidth = sw-sx-px, h1 = Math.sqrt(leftSensorWidth*leftSensorWidth + (pd*pd)), rightFOV = Math.atan(leftSensorWidth/h1), rightSensorWidth = sw - leftSensorWidth, h2= Math.sqrt(rightSensorWidth*rightSensorWidth + (pd*pd)), leftFOV = Math.atan(rightSensorWidth/h2), lowerSensorHeight = py-sy, upperFOV = Math.atan(lowerSensorHeight/Math.sqrt(lowerSensorHeight*lowerSensorHeight+(pd*pd))), upperSensorHeight = sh-lowerSensorHeight, lowerFOV = Math.atan(upperSensorHeight/Math.sqrt(upperSensorHeight*upperSensorHeight+(pd*pd)));
                GenericDialog gd2 = new GenericDialog("Field-of view Calculations");
                gd2.addMessage("The left view field is " + IJ.d2s(leftFOV) + " radians.");
                gd2.addMessage("The right view field is " + IJ.d2s(rightFOV) + " radians.");
                gd2.addMessage("The upper view field is " + IJ.d2s(upperFOV) + " radians.");
                gd2.addMessage("The lower view field is " + IJ.d2s(lowerFOV) + " radians.");
                gd2.addMessage("The total view field is " + IJ.d2s((leftFOV+rightFOV)*(upperFOV+lowerFOV)) + " radians^2.");
                gd2.showDialog();
        } 
}
